@@ -104,6 +104,10 @@ class HelmertFactory(Factory):
             return cls(1.00530, 0.00079, -1.90921, -0.00060, -0.54157, -0.00144, -26.78138,
                        -0.06667, 0.42027, 0.75744, -10.93206, 0.05133, 0.36891, -0.07201, 2010)
 
+        elif ref_frame == Reference.ITRF20:
+            return cls(1.00390, 0.00079, -1.90961, -0.00070, -0.54117, -0.00124, -26.78138,
+                       -0.06667, 0.42027, 0.75744, -10.93206, 0.05133, -0.05109, -0.07201, 2010)
+
         else:
             raise KeyError(ref_frame)
 
